---
title: Planck-Tapered Broken Power Law Plus Two Peaks
description: API reference for the corresponding sampler implementation.
---

::: gwmock_pop.samplers.planck_tapered_broken_power_law_plus_two_peaks
